<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\Brand;
use App\Form\BrandType;
use App\Traits\FormControllerTrait;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\{Request, Response};
use Symfony\Component\Routing\Annotation\Route;

#[Route('/brand')]
class BrandController extends AbstractController
{
    use FormControllerTrait;

    protected const ENTITY        = Brand::class;
    protected const TEMPLATE_PATH = 'brand/';
    protected const ROUTE_PREFIX  = 'brand_';
    protected const FORM          = BrandType::class;

    public function __construct(private readonly EntityManagerInterface $entityManager)
    {
    }

    #[Route('/', name: 'brand_index', methods: ['GET'])]
    public function index(): Response
    {
        return $this->itemListView('brands', [
            'name' => 'asc',
        ]);
    }

    #[Route('/new', name: 'brand_new', methods: ['GET', 'POST'])]
    public function new(Request $request): Response
    {
        return $this->itemCreate($request, 'brand');
    }

    #[Route('/{id}', name: 'brand_show', methods: ['GET'])]
    public function show(Brand $brand): Response
    {
        return $this->itemView($brand, 'brand');
    }

    #[Route('/{id}/edit', name: 'brand_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Brand $brand): Response
    {
        return $this->itemUpdate($request, $brand, 'brand');
    }

    #[Route('/{id}', name: 'brand_delete', methods: ['POST'])]
    public function delete(Request $request, Brand $brand): Response
    {
        return $this->deleteCSRF($request, $brand);
    }
}
