<?php

namespace App\Controller;

use App\Entity\Fpu;
use App\Form\FpuType;
use App\Traits\FormControllerTrait;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/fpu')]
class FpuController extends AbstractController
{
	use FormControllerTrait;

	protected const ENTITY        = Fpu::class;
	protected const TEMPLATE_PATH = 'fpu/';
	protected const ROUTE_PREFIX  = 'fpu_';
	protected const FORM          = FpuType::class;

	public function __construct(private readonly EntityManagerInterface $entityManager)
	{
	}

    #[Route('/', name: 'fpu_index', methods: ['GET'])]
    public function index(): Response
    {
		return $this->indexView('fpus', []);
    }

    #[Route('/new', name: 'fpu_new', methods: ['GET', 'POST'])]
    public function new(Request $request): Response
    {
		return $this->itemCreate($request, 'fpu');
    }

    #[Route('/{id}', name: 'fpu_show', methods: ['GET'])]
    public function show(Fpu $fpu): Response
    {
		return $this->itemView($fpu, 'fpu');
    }

    #[Route('/{id}/edit', name: 'fpu_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Fpu $fpu): Response
    {
		return $this->itemUpdate($request, $fpu, 'fpu');
    }

    #[Route('/{id}', name: 'fpu_delete', methods: ['POST'])]
    public function delete(Request $request, Fpu $fpu): Response
    {
		return $this->deleteCSRF($request, $fpu);
    }
}
